/*
Copyright (c) 2005-2010 Nokia Corporation and/or its subsidiary(-ies). All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

* Redistributions of source code must retain the above copyright notice, this
 list of conditions and the following disclaimer.
* Redistributions in binary form must reproduce the above copyright notice,
 this list of conditions and the following disclaimer in the documentation
 and/or other materials provided with the distribution.
* Neither the name of Nokia Corporation nor the names of its contributors
 may be used to endorse or promote products derived from this software
 without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

Description: 
*/



#ifndef __EXAMPLEAPP_H__
#define __EXAMPLEAPP_H__

#include <e32test.h>
#include <bacline.h>
#include "RTPFileStreamer.h"

_LIT(KTitle,"RTCP App" );
_LIT(KDestAddr,"2130706433" );
_LIT(KDestPort,"9000" ); 
_LIT(KLocalPort,"9000" ); 
_LIT(KsFileName,"source.dat" ); 
_LIT(KdFileName,"target.dat" );
_LIT(KSize,"100" );

/**
RTP active console observer
*/
class MActiveConsoleNotify
	{
public:
	virtual void KeyPressed(TChar aKey) =0;
	};
/**
RTP active console
*/
class CActiveConsole : public CActive
	{
	public:
		static CActiveConsole* NewL(MActiveConsoleNotify& aNotify,const TDesC& aTitle,const TSize& aSize);
		void RequestKey();		
		inline CConsoleBase& Console() const 
			{
			return *iConsole;
			};
		~CActiveConsole();
	private:
		void RunL();
		void DoCancel();
		void DrawCursor();
		CActiveConsole(MActiveConsoleNotify& aNotify);
		void ConstructL(const TDesC& aTitle,const TSize& aSize);
	private:
		CConsoleBase*			iConsole;
		MActiveConsoleNotify&	iNotify;
	};
/**
RTP example application	
*/
class CExampleApp : public CBase, public MActiveConsoleNotify, public MFileStreamerObserver
	{
public:
	static CExampleApp* NewL();

	void StartL();
	void Stop();
	~CExampleApp();
	void KeyPressed(TChar aKey);
	void ReadError(TInt aError);
public:
	virtual void NotifyPacketSent();
	virtual void NotifyPacketReceived();
	virtual void NotifyComplete();
	virtual void NotifyError();
private:
	CExampleApp();
	void ConstructL();
	void DrawMonitor();
private:
	CActiveConsole*			iActiveConsole;
	CActiveConsole*			iMonitorConsole;
	TInt					iSent;
	TInt					iRecv;
	CRtpFileStreamer*		iStreamer;
	RSocketServ				iSockServ;
	};

#endif // __EXAMPLEAPP_H__
